@@ -17,7 +17,7 @@ class MainWindow(QtGui.QMainWindow):
 
         #Initial Settings
         self.resize(800,480)
-        self.setWindowTitle('London Tube Map 0.2')
+        self.setWindowTitle('London Tube Map 0.2.5')
         
         #Open Image
         self.ChargerScene()
